# -*- coding:UTF-8 -*-
# @Author:Chay
# @TIME:2024/07/21 17:20
# @FILE:xiaogongju.py
# @Software:IDLE 3.9.6
import random,string
'''
函数名：quzheng
调用形式：quzheng(num,mode)
:param num 待取整的数字 float
:param mode 模式 1（向下取整）/2（向上取整） 不在选择范围内则抛出异常
:return 取整后的数字
作用：对数字进行取整
'''
def quzheng(num:float,mode:int) -> int:
    if mode == 1:
        return int(num)
    elif mode == 2:
        return int(num)+1
    else:
        raise ValueError("mode需在1、2两数之间，不得为其他数！")
'''
函数名：daorxiao
调用形式：daorxiao(args,mode)
:param args 待转换的字符串
:param mode 模式 1（大写转小写）/2（小写转大写） 不在选择范围内则抛出异常
:return zifu 转换后的字符串
作用：大小写转换
'''
def daorxiao(args:str,mode:int) ->str:
    zongzifu = []
    zifu2=""
    gongneng1 = mode
    if gongneng1 == 1:
        for i in args:
            if ord(i)>=65 and ord(i)<=90:
                zifu = i
                zifu1 = chr(ord(zifu) + 32)
                zongzifu.append(zifu1)
            else:
                zongzifu.append(i)                
        for i in zongzifu:
            zifu2 += i
        return zifu2
    elif gongneng1 == 2:
        for i in args:
            if ord(i)>=97 and ord(i)<=122:
                zifu = i
                zifu1 = chr(ord(zifu) - 32)
                zongzifu.append(zifu1)
            else:
                zongzifu.append(i)
        for i in zongzifu:
            zifu2 += i
        return zifu2
    else:
        raise TypeError("TypeError:模式错误！")

'''
函数名：twonumbers_TheBiggestCommonfactor
调用形式：a = twonumbers_TheBiggestCommonfactor(num1,num2)
:param num1 第一个数
:param num2 第二个数
:return num1和num2的最大公因数
作用：求最大公因数
'''
def twonumbers_TheBiggestCommonfactor(num1:int,num2:int) -> int:
    lst = []
    for i in range(1,max(num1,num2)+1):
        if num1 % i == 0 and num2 % i == 0:
            lst.append(i)
    return max(lst)

'''
函数名：twonumbers_TheMinimumCommonmultiple
调用形式：a = twonumbers_TheMinimumCommonmultiple(num1,num2)
:param num1 第一个数
:param num2 第二个数
:return num1和num2的最小公倍数
作用：求最小公倍数
'''
def twonumbers_TheMinimumCommonmultiple(num1:int,num2:int) -> int:
    lst = []
    for i in range(1,max(num1,num2)+1):
        if num1 % i == 0 and num2 % i == 0:
            lst.append(i)
    return num1 * num2 // max(lst)

'''
函数名：chouqusuiji
调用形式：a = chouqusuiji(num1,num2,mode,weishu)
:param num1 抽取随机数中区间的最小值
:param num2 抽取随机数中区间的最大值
:param mode 1:随机数   2:随机字符串    3:随机颜色代码（#......）
:param weishu 在随机字符串中字符串的位数
作用：抽取随机
'''
def chouqusuiji(num1:int,num2:int,mode:int,weishu:int) -> str:
    if mode==1:
        return str(random.randint(num1,num2))
    elif mode==2:
        chars = string.ascii_letters + string.digits
        a=""
        for i in range(weishu):
            a += random.choice(chars)
        return a
    elif mode==3:
        return "#"+chouqusuiji(1,10,2,6)

'''
函数名：kaisamima
调用形式：a = kaisamima(arg,mode,n)
:param arg 需要加解密的字符串
:param mode 1:加密  2:解密
:param n 位移量
作用：加解密凯撒密码
'''
def kaisamima(arg:str,mode:int,n:int) -> str:
    a = []
    for i in range(97,123):
        a.append(chr(i))
    b = []
    for i in range(65,91):
        b.append(chr(i))
    a *= 2
    b *= 2
    c = ""
    if mode == 1:
        for i in range(len(arg)):
            if 65 <= ord(arg[i]) and ord(arg[i]) <= 90:
                c += b[b.index(arg[i])+n]
            elif 97 <= ord(arg[i]) and ord(arg[i]) <= 122:
                c += a[a.index(arg[i])+n]
            else:
                raise ValueError("arg应为只含字母的字符串")
        return c
    elif mode == 2:
        for i in range(len(arg)):
            if 65 <= ord(arg[i]) and ord(arg[i]) <= 90:
                c += b[b.index(arg[i])-n]
            elif 97 <= ord(arg[i]) and ord(arg[i]) <= 122:
                c += a[a.index(arg[i])-n]
            else:
                raise ValueError("arg应为只含字母的字符串")
        return c
    else:
        raise TypeError("TypeError:模式错误！")

def f(a:float,n:int,m:int) -> int:
    if 0<n and n<m and m <= 9:
        # 将浮点数 a 转换为整数部分和小数部分  
        integer_part = int(a)  
        decimal_part = round((a - integer_part) * 10, 2)  # 保留两位小数，以便比较  
        first_decimal_digit = int(decimal_part[1:])  # 提取小数部分的第一位  
    
        # 根据规则进行判断  
        if first_decimal_digit <= n:  
            return integer_part  
        elif first_decimal_digit >= m:  
            return integer_part + 1  
        else:  
            # 当 m-n > 1，并且小数部分第一位在 n 和 m 之间时  
            if integer_part % 2 == 1:  
                return integer_part + 1  
            else:  
                return integer_part
    else:
        raise ValueError("不符合规则")


# -*- coding:UTF-8 -*-
# @Author:Chay
# @TIME:2022/12/25 9:03
# @FILE:erfenchazhao_py.py
# @Software:IDLE 3.9.6

import time

'''
函数名：erfenchazhao
调用形式：a = erfenchazhao(yuanlst,shengxulst,target)
:param yuanlst 原序列
:param shengxulst 升序列表（原序列改编）
:param target 查找值
:return 查找结果（索引，用时，次数）
作用：查找列表中的值
'''
def erfenchazhao(yuanlst,shengxulst,target):
    start = 0
    count = 0
    end = len(shengxulst)-1
    if target not in shengxulst:
        return None
    while True:
        count += 1
        mid = (start+end)//2
        if target < shengxulst[mid]:
            end = mid-1
            continue
        elif target > shengxulst[mid]:
            start = mid + 1
            continue
        else:
            return yuanlst.index(target)


# -*- coding:UTF-8 -*-
# @Author:Chay
# @TIME:2024/08/31 16:29
# @FILE:Allinone.py
# @version:4.0.2
# @Software:Visual Studio Code
import random
import module.calculator as calculator
import module.erfenchazhao_py  as erfenchazhao_py
import module.math_cal_py as math_cal
import module.student_py as student_py
import module.tuxing_cal as tuxing_cal
import module.xiaogongju as xiaogongju
import lotterytickets as lt
import numberandchinese as ntoc
import module.shujuku as sjck
def allinone(fuwu,mode,*args):
    """
    :param fuwu 需要服务的功能
    :param mode 部分功能需要的模式（详见Github中All-in-one2.4.0分支的Wiki页）
    :param *args 可变参数，表示需要传入的参数，建议用元组或列表类型，具体所需类型见README.MD
    :return: 0：正常，1：不正常，其他返回值表示功能的结果

    功能（按代码顺序排序，不分先后）：大小写互换、抽取随机数、求最小公倍数、求最大公倍数、图形计算器、小学学生信息管理系统、二分查找、求余、向下取整、向上取整、多个数求和、多个数求差、多个数求积、判断闰年、判断是否为质数、整数、小数计算（加减乘除）、分数计算（加减乘除）......（具体见Github All-in-one2.4.0分支Readme.md文件）
    """
    sjck.sjc(fuwu,str(mode),str(args))
    if fuwu == "大小写互换":
        return xiaogongju.daorxiao(args[0],mode)
    elif fuwu == "抽取随机":
        return xiaogongju.chouqusuiji(args[0],args[1],mode,args[2])
    elif fuwu == "求最小公倍数":
        num1 = args[0]
        num2 = args[1]
        for i1 in range(max(num1, num2), num1 * num2 + 1):
            if i1 % num1 == 0 and i1 % num2 == 0:
                return i1
    elif fuwu == "求最大公因数":
        num1 = args[0]
        num2 = args[1]
        return xiaogongju.twonumbers_TheBiggestCommonfactor(num1,num2)
    # elif fuwu == "快速排列":
    #     kuaisupailie()
    elif fuwu == "求解方程":
        return calculator.yiyuannci(args[0],args[1])
    elif fuwu=="反转字符串":
        return calculator.fanzhuanzifuchuan(args[0])
    elif fuwu=="判断质数":
        return calculator.isparam(args[0])
    elif fuwu=="判断回文数":
        return calculator.ishuiwenshu(args[0])
    elif fuwu=="判断回文质数":
        return calculator.ishuiwenzhishu(args[0])
    elif fuwu=="求斐波那契数列的第n项":
        return calculator.fab(args[0])
    elif fuwu=="判断斐波那契数":
        return calculator.isfab(args[0])
    elif fuwu=="判断斐波那契回文质数":
        return calculator.isfabhuiwenzhishu(args[0])
    elif fuwu=="判断斐波那契回文数":
        return calculator.isfabhuiwenshu(args[0])
    elif fuwu=="判断斐波那契质数":
        return calculator.isfabparam(args[0])
    elif fuwu=="求泰波那契序列的第n项":
        return calculator.tribonacci(args[0])
    elif fuwu=="判断泰波那契数":
        return calculator.istribonacci(args[0])
    elif fuwu=="判断泰波那契回文质数":
        return calculator.istribonaccihuiwenshuparam(args[0])
    elif fuwu=="判断泰波那契回文数":
        return calculator.istribonaccihuiwenshu(args[0])
    elif fuwu=="判断泰波那契质数":
        return calculator.istribonacciparam(args[0])
    elif fuwu=="求第n个完全平方数":
        return calculator.wanquanpingfangshu(args[0])
    elif fuwu=="判断完全平方数":
        return calculator.iswanquanpingfangshu(args[0])
    elif fuwu=="判断斐波那契完全平方数":
        return calculator.isfabwanquanpingfangshu(args[0])
    elif fuwu=="判断泰波那契序列完全平方数":
        return calculator.istribonacciwanquanpingfangshu(args[0])
    elif fuwu == "进制转换":
        return calculator.jinzhizhuanhuan(args[0],args[1],args[2])
    elif fuwu=="math库计算器":
        return math_cal.math_cal(mode,args[0],args[1])
    elif fuwu == "分解因式":
        return calculator.factorization(args[0])
    elif fuwu == "提取密码":
        return calculator.mima(args[0],args[1])
    elif fuwu == "凯撒密码计算":
        return xiaogongju.kaisamima(args[0],mode,args[1])
    elif fuwu == "彩票一体机":
        return lt.lotterytickets(args[0],args[1],mode)
    elif fuwu == "数字中文互转":
        if mode == 1:
            return ntoc.No2Cn(args[0])
        else:
            return ntoc.chinese2digits(args[0])
    elif fuwu == "图形计算器":
        while True:
            huida = args[0]
            try:
                args2=[]
                for i in range(1,len(args)):
                    args2.append(args[i])
                if tuxing_cal.tuxing(huida,mode,args2) != 1:
                    if tuxing_cal.tuxing(huida,mode,args2) != 2:
                        return tuxing_cal.tuxing(huida,mode,args2)
                    else:
                        return "不支持此图形的计算！"
                else:
                    return "不支持该功能！"
            except ValueError:
                return ("输入无效！")
    elif fuwu == "小学学生信息管理系统":
        student_py.student()
    elif fuwu == "二分查找":
        while True:
            d = args[0]
            if d == "yes":
                a = args
                b = sorted(a)
                c = args[-1]
                diaoyong  = erfenchazhao_py.erfenchazhao(a, b, c)
                return(diaoyong)
            elif d == "no":
                return 0
            else:
                return ("指令无效！")
    elif fuwu == "取整":
        return xiaogongju.quzheng(args[0],args[1])
    elif fuwu == "判断闰年":
        return calculator.isleapyear(args[0])
    elif fuwu == "整数/小数计算":
        return calculator.xiaoorzhengjisuan(args[0],args[1],args[2])
    elif fuwu == "分数计算":
        return calculator.fenjisuan(args[0],args[1],args[2])
    elif fuwu == "分数小数转换":
        return calculator.xiaoorfen(args[0],mode)
    elif fuwu == "比大小":
        return args[0]>args[1]
    elif fuwu == "年龄计算":
        return args[0]-args[1]
    elif fuwu == "开n次方":
        return args[0] ** (1/args[1])
    elif fuwu == "华氏度摄氏度转换":
        return calculator.FtemporCtemp(mode,args[0])
    elif fuwu == "混合运算":
        if mode == 1:
            return args[0]+args[1]-args[2]
        elif mode == 2:
            return (args[0]+args[1])*args[2]
        elif mode == 3:
            return (args[0]+args[1])/args[2]
        elif mode == 4:
            return args[0]-args[1]+args[2]
        elif mode == 5:
            return (args[0]-args[1])*args[2]
        elif mode == 6:
            return (args[0]-args[1])/args[2]
        elif mode == 7:
            return args[0]*args[1]+args[2]
        elif mode == 8:
            return args[0]*args[1]-args[2]
        elif mode == 9:
            return args[0]*args[1]/args[2]
        elif mode == 10:
            return args[0]/args[1]+args[2]
        elif mode == 11:
            return args[0]/args[1]-args[2]
        elif mode == 12:
            return args[0]/args[1]*args[2]
        elif mode == 13:
            return args[0]/args[1]/args[2]
    elif fuwu == "货币转换":
        return calculator.duihuan(mode,args[0]) 
    else:
        jieshulist = ["功能无效！", "无法实现服务！", "暂时还在开发！"]
        b = random.choice(jieshulist)
        return b



# -*- coding:UTF-8 -*-
# @Author:Chay
# @TIME:2024/07/23 17:00
# @FILE:Allinone.py
# @version:4.0.1
# @Software:Visual Studio Code

from sqlite3 import *
from os import * 
def sjc(fuwu:str,mode:int,canshu:str):
    makedirs("D:\\all-in-one", exist_ok=True)   
    conn = connect("D:\\all-in-one\\All in one 库使用数据.db")  
    cursor = conn.cursor()  
    sql_create_table = """  
    CREATE TABLE IF NOT EXISTS "All-in-one库使用数据" (
        "ID"	INTEGER NOT NULL UNIQUE,
        "使用功能"	TEXT NOT NULL,
        "模式" TEXT
        "参数"	TEXT NOT NULL,
        PRIMARY KEY("ID" AUTOINCREMENT)
    );
    """
    cursor.execute(sql_create_table)
    conn.commit() 

    sql_insert='''
    INSERT INTO "All-in-one库使用数据" ("使用功能","模式","参数")  
    VALUES (?, ?, ?);
    '''
    cursor.execute(sql_insert, (fuwu,mode,canshu))
    conn.commit()

    cursor.close()  
    conn.close() 


# -*- coding:UTF-8 -*-
# @Author:Chay
# @TIME:2024/08/31 08:05
# @FILE:calculator.py
# @Software:Visual Studio Code
import math,itertools,random,re
from cmath import sqrt as csqrt
from sympy import *
from fractions import *

'''
函数名：FtemporCtemp
调用形式：a = FtemporCtemp(mode,FtemporCtemp)
:param mode 模式 ℃to℉（摄氏度转为华氏度）/℉to℃（华氏度转为摄氏度） 模式不在选择范围内会抛出异常
:return 转换后的温度（不带单位）
作用：华氏度与摄氏度转换
'''
def FtemporCtemp(mode:str,FtemporCtemp:float) -> float:
    if mode == "℃to℉":
        return FtemporCtemp*9/5+32
    elif mode == "℉to℃":
        return (FtemporCtemp-32)*5/9
    else:
        raise TypeError("TypeError:模式错误！")

'''
函数名：duihuan
调用形式：a = duihuan(mode,money)
:param mode 模式 1~16 对应不同的货币转换，汇率也不同 模式不在选择范围内会抛出异常
:param money 要兑换的金额（以模式箭头前的货币单位作为1单位量）
:return 转换后的货币数量
作用：货币交换
'''
def duihuan(mode:int,money:float) -> float:
    if mode == 1:
        return 0.14 * money #CNY to USD
    elif mode == 2:
        return 20.71 * money #CNY to JPY
    elif mode == 3:
        return 7.2 * money #USD to CNY
    elif mode == 4:
        return 149.02 * money #USD to JPY
    elif mode == 5:
        return 0.048 * money #JPY to CNY
    elif mode == 6:
        return 0.0067 * money #JPY to USD
    elif mode == 7:
        return 0.89 * money #MOP to CNY
    elif mode == 8:
        return 1.12 * money #CNY to MOP
    elif mode == 9:
        return 0.92 * money #HKD to CNY
    elif mode == 10:
        return 1.09 * money #CNY to HKD
    elif mode == 11:
        return 0.23 * money #TWD to CNY
    elif mode == 12:
        return 4.40 * money #CNY to TWD
    elif mode == 13:
        return 9.17 * money #GBP to CNY
    elif mode == 14:
        return 0.11 * money #CNY to GBP
    elif mode == 15:
        return 7.84 * money #EUR to CNY
    elif mode == 16:
        return 0.13 * money #CNY to EUR
    else:
        raise TypeError("TypeError:模式错误！")
'''
函数名：yiyuanerci
调用形式：a = yiyuanerci(float1,float2,float3)
:param fangcheng 方程 类型：str 要求：为ax+b=0 or ax^2+bx+c=0 or ax^3+bx^2+cx+d=0的形式
:param mode 方程的最高次数 类型：int 为1、2、3中的一个
:return gen 方程的解 类型：tuple
作用：求解一元一、二、三次方程
'''
def yiyuannci(fangcheng:str,mode:int) -> tuple:
    if mode == 1:
        l = fangcheng.split("=")
        l = l[0].split("+")
        for i in range(len(l)-1):
            l[i] = int(l[i][0])
        l[-1] = int(l[-1])
        return (-(l[1]/l[0]))
    elif mode == 2:
        match = re.match(r'(\d+)x\^2\s*([-+])\s*(\d*)x\s*([-+])\s*(\d+)\s*=\s*0', fangcheng)
        
        # 提取系数
        a = int(match.group(1))
        sign_b = match.group(2)
        b_str = match.group(3)
        sign_c = match.group(4)
        c = int(match.group(5))

        # 处理b和c的符号
        b = int(b_str) if sign_b == '+' else -int(b_str)
        c = int(c) if sign_c == '+' else -int(c)

        # 计算判别式
        delta = b**2 - 4*a*c

        # 根据判别式的值求解方程
        if delta >= 0:
            # 实数解
            root1 = (-b + math.sqrt(delta)) / (2*a)
            root2 = (-b - math.sqrt(delta)) / (2*a)
            return (root1, root2)
        else:
            # 复数解
            real_part = -b / (2*a)
            imag_part = csqrt(-delta) / (2*a)
            return (complex(real_part, imag_part.real), complex(real_part, -imag_part.real))

    elif mode == 3:
        fangcheng = fangcheng.replace("^","**")
        fangcheng = fangcheng.replace("=0","")
        # 定义符号
        x = symbols('x')
        
        # 使用sympify将字符串转换为表达式
        equation_expr = sympify(fangcheng)
        
        # 创建等式对象
        eq = Eq(equation_expr, 0)
        
        # 解方程
        solutions = solve(eq, x)
        
        return tuple(solutions)
    else:
        raise ValueError("param \"mode\" is >0 and <= 3 and \"mode\" is type int! mode参数需为1,2,3中的一个")

'''
函数名：fanzhuanzifuchuan
调用形式：a = fanzhuanzifuchuan(s)
:param s 需要反转的字符串 类型：str
:return s1 翻转后的字符串 类型：str
作用：反转字符串
'''

def fanzhuanzifuchuan(s:str) -> str:
    s=str(s)
    s1=""
    for i in range(len(s)-1,-1,-1):
        j=0
        s1 += s[i]
        j+=1
    return s1

'''
函数名：isparam
调用形式：a = isparam(d)
:param d  类型：int
:return x 是否为质数 类型：bool(True or False)
作用：判断质数
'''
def isparam(d:int) -> bool:
    if d <= 1:
        return False
    for i in range(2,math.sqrt(d)+1):
        if d%i==0:
            return False
    return True

'''
函数名：ishuiwenshu
调用形式：a = ishuiwenshu(s)
:param d  类型：int
:return x 是否为回文数 类型：bool(True or False)
作用：判断回文数
'''
def ishuiwenshu(d:int) -> bool:
    d1=int(fanzhuanzifuchuan(str(d)))
    if d1==d:
        return True
    else:
        return False

'''
函数名：ishuiwenzhishu
调用形式：a = ishuiwenzhishu(d)
:param d  类型：int
:return x 是否为回文质数 类型：bool(True or False)
作用：判断回文质数
'''
def ishuiwenzhishu(d:int) -> bool:
    d1=int(fanzhuanzifuchuan(str(d)))
    if d1==d:
        if isparam(d):
            return True
        else:
            return False
    else:
        return False

'''
函数名：fab
调用形式：a = fab(d)
:param x  类型：int
:return a[x-1] 斐波那契数列的第x位
作用：求斐波那契数列的第x位
'''
def fab(x:int) -> int:
    a=[1,1]
    for i in range(2,x):
        a.append(a[i-1]+a[i-2])
    for i in range(x):
        print(a[i]," ")
    return a[x-1]

'''
函数名：isfab
调用形式：a = isfab(d)
:param d  类型：int(0<d<=12586269025)
:return x 是否为斐波那契数列中的一个数 类型：bool(True or False)
作用：是否为斐波那契数列中的一个数
'''
def isfab(x:int) -> bool:
    a=[1,1]
    for i in range(2,int(math.sqrt(x+2))):
        a.append(a[i-1]+a[i-2])
    if x not in a:
        return False
    else:
        return True

'''
函数名：isfabparam
调用形式：a = isfabparam(d)
:param d  类型：int(0<d<=12586269025)
:return x 是否是斐波那契质数 类型：bool(True or False)
作用：是否为斐波那契数列中的一个数且为一个质数
'''
def isfabparam(x:int) -> bool:
    if isfab(x) and isparam(x):
        return True
    else:
        return False

'''
函数名：isfabhuiwenshu
调用形式：a = isfabhuiwenshu(d)
:param d  类型：int(0<d<=12586269025)
:return x 是否是斐波那契回文数 类型：bool(True or False)
作用：是否为斐波那契数列中的一个数且为一个回文数
'''
def isfabhuiwenshu(x:int) -> bool:
    if isfab(x) and ishuiwenshu(x):
        return True
    else:
        return False

'''
函数名：isfabhuiwenzhishu
调用形式：a = isfabhuiwenzhishu(d)
:param d  类型：int(0<d<=12586269025)
:return x 是否是斐波那契回文质数 类型：bool(True or False)
作用：是否为斐波那契数列中的一个数且为一个回文质数
'''
def isfabhuiwenzhishu(x:int) -> bool:
    if isfab(x) and ishuiwenzhishu(x):
        return True
    else:
        return False

'''
函数名：isleapyear
调用形式：a = isleapyear(d)
:param d  类型：int
:return x 对应年份是否是闰年 类型：bool(True or False)
作用：判断闰年
'''   
def isleapyear(x) -> bool:
    if x%4==0:
        if x%100==0:
            if x%400==0:
                return True
            else:
                return False
        else:
            return True
    else:
        return False

'''
泰波那契序列 Tn 定义如下： 
T0 = 0, T1 = 1, T2 = 1, 且在 n >= 0 的条件下 Tn+3 = Tn + Tn+1 + Tn+2
函数名：tribonacci
调用形式：a = tribonacci(d)
:param x  类型：int
:return a[x-1] 泰波那契序列的第x位
作用：求泰波那契序列的第x位
'''
def tribonacci(n:int) -> int:
    d=[0,1,1]
    if n<=2:
        return d[n]
    else:
        for i in range(3,n+1):
            d.append(d[i-3]+d[i-2]+d[i-1])
        return d[n]

'''
泰波那契序列 Tn 定义如下： 
T0 = 0, T1 = 1, T2 = 1, 且在 n >= 0 的条件下 Tn+3 = Tn + Tn+1 + Tn+2
函数名：istribonacci
调用形式：a = istribonacci(d)
:param x  类型：int
:return x 是否属于泰波那契序列中的一个数（True or False）
作用：判断是否属于泰波那契序列中的一个数
'''
def istribonacci(n:int) -> bool:
    a=[0,1,1]
    if n>=10000:
        for i in range(3,int(math.sqrt(n+3))):
            a.append(a[i-1]+a[i-2]+a[i-3])
    elif n>=1389537:
        for i in range(3,int(math.sqrt(int(math.sqrt(n+3))))):
            a.append(a[i-1]+a[i-2]+a[i-3])
    else:
        for i in range(3,int((n+3))):
            a.append(a[i-1]+a[i-2]+a[i-3])
    if n not in a:
        return False
    else:
        return True

'''
泰波那契序列 Tn 定义如下： 
T0 = 0, T1 = 1, T2 = 1, 且在 n >= 0 的条件下 Tn+3 = Tn + Tn+1 + Tn+2
函数名：istribonaccihuiwenshu
调用形式：a = istribonaccihuiwenshu(d)
:param x  类型：int
:return x 是否是泰波那契序列回文数（True or False）
作用：判断泰波那契序列回文数
'''
def istribonaccihuiwenshu(n:int) -> bool:
    if istribonacci(n) and ishuiwenshu(n):
        return True
    else:
        return False

'''
泰波那契序列 Tn 定义如下： 
T0 = 0, T1 = 1, T2 = 1, 且在 n >= 0 的条件下 Tn+3 = Tn + Tn+1 + Tn+2
函数名：istribonaccihuiwenshuparam
调用形式：a = istribonaccihuiwenshuparam(d)
:param x  类型：int
:return x 是否是泰波那契序列回文质数（True or False）
作用：判断泰波那契序列回文质数
'''
def istribonaccihuiwenshuparam(n:int) -> bool:
    if isfabhuiwenshu(n) and isparam(n):
        return True
    else:
        return False

'''
泰波那契序列 Tn 定义如下： 
T0 = 0, T1 = 1, T2 = 1, 且在 n >= 0 的条件下 Tn+3 = Tn + Tn+1 + Tn+2
函数名：istribonacciparam
调用形式：a = istribonacciparam(d)
:param x  类型：int
:return x 是否是泰波那契序列质数（True or False）
作用：判断泰波那契序列质数
'''
def istribonacciparam(n:int) -> bool:
    if istribonacci(n) and isparam(n):
        return True
    else:
        return False

'''
函数名：iswanquanpingfangshu
调用形式：a = iswanquanpingfangshu(d)
:param d  类型：int
:return x d是否是完全平方数 类型：bool(True or False)
作用：判断完全平方数
'''   
def iswanquanpingfangshu(num:int) -> bool:
    a=math.sqrt(num)
    if int(a)==a:
        return True
    else:
        return False

'''
函数名：wanquanpingfangshu
调用形式：a = wanquanpingfangshu(d)
:param d  类型：int
:return x 第d个完全平方数
作用：求第d个完全平方数
'''
def wanquanpingfangshu(num:int) -> int:
    return num**2

'''
函数名：isfabwanquanpingfangshu
调用形式：a = isfabwanquanpingfangshu(d)
:param d  类型：int
:return x d是否是斐波那契完全平方数 类型：bool(True or False)
作用：判断斐波那契完全平方数
'''  
def isfabwanquanpingfangshu(num:int) -> bool:
    return isfab(num) and iswanquanpingfangshu(num)

'''
泰波那契序列 Tn 定义如下： 
T0 = 0, T1 = 1, T2 = 1, 且在 n >= 0 的条件下 Tn+3 = Tn + Tn+1 + Tn+2
函数名：istribonacciwanquanpingfangshu
调用形式：a = istribonacciwanquanpingfangshu(d)
:param x  类型：int
:return x 是否是泰波那契序列完全平方数（True or False）
作用：判断泰波那契序列完全平方数
'''
def istribonacciwanquanpingfangshu(num:int) -> bool:
    return istribonacci(num) and iswanquanpingfangshu(num)

'''
函数名：jinzhizhuanhuan
调用形式：a =  jinzhizhuanhuan(a,b,c)
:param a c的进制数 (2<=a<=36)
:param b 结果的进制数 (2<=a<=36)
:param c 需转换的数 无需前缀且需符合a进制规则
:return z 结果
作用：进行进制转换
'''
def jinzhizhuanhuan(a:int,b:int,c:str) -> str:
    if a == b:
        return c
    elif a == 10  and b != 10:
        num = int(c)  
        result = ""  
        while num > 0:  
            remainder = num % b  
            if remainder >= 10:  
                result += chr(remainder - 10 + ord('A'))  
            else:  
                result += str(remainder)  
            num //= b
        return result[::-1] 
    elif a != 10 and b == 10:
        ans=0
        tmp=1
        n=len(c)
        for i in range(n-1,-1,-1):
            base = 0
            if c[i] >= 'A' and c[i] <= 'Z':
                base = c[i]-'A'+10
            else:
                base = ord(c[i])-ord('0')
            ans += tmp*base
            tmp *= a
        return str(ans)

    else:
        return jinzhizhuanhuan(10,b,jinzhizhuanhuan(a,10,c))
    
'''
函数名：factorization
调用形式：a = facforization(num)
:param num 需因式分解的自然数
:return factor 因式分解的结果
作用：对一个数进行因式分解
'''
def factorization(num:int) -> list[int]:
    factor = []
    while num > 1:
        for i in range(num - 1):
            k = i + 2
            if num % k == 0:
                factor.append(k)
                num = int(num / k)
                break
    return factor

'''
函数名：mima
调用形式：a = mima(num,n)
:param num 提取密码的数字
:param n 密码位数
:return z 结果
作用：对一个数提取密码
'''
def mima(num:int,n:int) -> int:
    factor = factorization(num)
    y = []
    if n <= len(str(max(factor))):
        for i in itertools.combinations(factor,n):
            y.append(int(''.join('%d'%o for o in i)))
        return random.choice(y)
    else:
        return 0
def xiaoorfen(num:str,mode:int) -> str:
    if mode == 1: #小化分
        return Fraction(float(num)).limit_denominator()
    elif mode == 2: #分化小
        return eval(num)
    else:
        raise ValueError("mode Error!")
'''
函数名：xiaoorzhengjisuan
调用形式：a = xiaoorzhengjisuan(num1,num2,mode)
:param num1 运算数字1
:param num2 运算数字2
:param mode 模式（运算符+-*/**（乘方）中的一个）
:return z 结果
作用：小数、整数计算
'''
def xiaoorzhengjisuan(num1:float,num2:float,mode:str) -> float:
    return eval(str(num1)+mode+str(num2))

'''
函数名：fenjisuan
调用形式：a = fenjisuan(num1,num2,mode)
:param num1 运算数字1
:param num2 运算数字2
:param mode 模式（运算符+-*/**（乘方）中的一个）
:return z 结果
作用：分数计算
'''
def fenjisuan(num1:str,num2:str,mode:str) -> float:
    return Fraction(eval(str(xiaoorfen(num1,2))+mode+str(xiaoorfen(num2,2)))).limit_denominator()

'''
函数名：bmi
调用形式：a = bmi(weight,height)
:param weight 体重（KG）
:param height 身高（m）
:return BMI BMI指数
作用：计算BMI指数
'''
def bmi(weight:int,height:int) -> float:
    return weight/(height**2)


# -*- coding:UTF-8 -*-
# @Author:Chay
# @TIME:2022/12/24 15:17
# @FILE:tuxing_cal.py
# @Software:IDLE 3.9.6
'''
函数名：tuxing
调用形式：tuxing(huida)
:param huida 图形
:return 0
作用：进行图形计算
'''
import math
def tuxing(huida,mode,*args2):
    if huida == "长方体":
        huida1 = mode   #体积/面积/表面积/染色问题/容积/棱长总和
        huida2 = args2[0]
        huida3 = args2[1]
        huida4 = args2[2]
        if huida1 == "体积":
            shuchu = huida2 * huida3 * huida4
            return shuchu
        elif huida1 == "表面积":
            shuchu = (huida2 * huida3 + huida2 * huida4 + huida3 * huida4) * 2
            return shuchu
        elif huida1 == "染色问题":
            huida2 = int(huida2)
            huida3 = int(huida3)
            huida4 = int(huida4)
            if huida4 == 1:
                return("4个面染色的小正方体有4个。","3个面染色的小正方体有" + str((huida2 - 2) * 2 + (huida3 - 2) * 2) + "个。","2个面染色的小正方体有" + str((huida2 - 2) * (huida3 - 2)) + "个。")
            else:
                return("3个面染色的小正方体有8个。","2个面染色的小正方体有" + str(((huida2-2)+(huida3-2)+(huida4-2))*4) +"个。","1个面染色的小正方体有" + str(((huida2-2)*(huida3-2)+(huida2-2)*(huida4-2)+(huida3-2)*(huida4-2))*2) + "个。","0个面染色的小正方体有" + str((huida2-2)*(huida3-2)*(huida4-2)) + "个")
        elif huida1 == "棱长总和":
            shuchu = (huida2+huida3+huida4)*4
            return shuchu
        elif huida1 == "容积":
            shuchu = huida2*huida3*huida4
            return shuchu
        else:
            return 1
    elif huida == "正方体":
        huida1 = mode     #体积/面积/表面积/染色问题/容积/棱长总和
        huida2 = args2[0]
        if huida1 == "体积":
            shuchu = huida2 ** 3
            return shuchu
        elif huida1 == "表面积":
            shuchu = huida2 ** 2 * 6
            return shuchu
        elif huida1 == "棱长总和":
            shuchu = huida2 * 12
            return shuchu
        elif huida1 == "容积":
            shuchu = huida2 ** 3
            return shuchu
        elif huida1 == "染色问题":
            huida2 = int(huida2)
            if huida2 == 1:
                return("6个面染色的小正方体有1个")
            else:
                return("3个面染色的小正方体有8个。","2个面染色的小正方体有" + str((huida2-2)*12) + "个。","1个面染色的小正方体有" + str((huida2-2)**2*6) + "个。","0个面染色的小正方体有" + str((huida2-2)**3) + "个。")
        else:
            return 1
    elif huida == "正方形":
        huida1 = mode
        huida2 = args2[0]
        if huida1 == "面积":
            shuchu = huida2**2
            return shuchu
        elif huida1 == "边长之和":
            shuchu = huida2*4
            return shuchu
        elif huida1 == "折纸盒问题":
            huida3 = args2[1]
            V = (huida2-2*huida3)**2
            S = huida2**2-((huida3**2)*4)
            return("体积是：" + str(V) + "表面积是：" + str(S))
        else:
            return(1)
    elif huida == "长方形":
        huida1 = mode
        huida2 = args2[0]
        huida3 = args2[1]
        if huida1 == "面积":
            shuchu = huida2*huida3
            return shuchu
        elif huida1 == "周长":
            shuchu = (huida2+huida3)*2
            return shuchu
        elif huida1 == "折纸盒问题":
            huida4 = args2[2]
            V = (huida2-(2*huida4))*(huida3-(2*huida4))
            S = huida2*huida3-(huida4**2*4)
            return("体积是：" + str(V) + "表面积是：" + str(S))
        else:
            return 1
    elif huida == "平行四边形":
        huida1 = mode
        huida2 = args2[0]
        huida3 = args2[1]
        huida4 = args2[2]
        if huida1 == "面积":
            shuchu = huida2*huida3
            return shuchu
        elif huida1 == "周长":
            shuchu = (huida2+huida4)*2
            return shuchu
        elif huida1 == "折纸盒问题":
            huida5 = args2[3]
            S = huida2*huida3-(huida4**2)*4
            V = huida5*((huida4-2*huida5)*(huida2-2*huida5))
            return(f"体积是：{str(V)},表面积是：{str(S)}")
        else:
            return 1
    elif huida == "菱形":
        huida1 = mode
        huida2 = args2[0]
        huida3 = args2[1]
        if huida1 == "面积":
            shuchu = huida2*huida3
            return shuchu
        elif huida1 == "周长":
            shuchu = huida2*4
            return shuchu
        else:
            return 1
    elif huida == "三角形":
        huida1 = mode
        huida2 = args2[0]
        huida3 = args2[1]
        if huida1 == "面积":
            shuchu = huida2*huida3/2
            return shuchu
        elif huida1 == "周长":
            huida4 = args2[2]
            huida5 = args2[3]
            shuchu = huida2+huida4+huida5
            return shuchu
        else:
            return 1
    elif huida == "梯形":
        huida1 = mode
        huida2 = args2[0]
        huida3 = args2[1]
        huida4 = args2[2]
        if huida1 == "面积":
            shuchu = (huida2+huida3)*huida4/2
            return shuchu
        elif huida1 == "周长":
            huida5 = args2[3]
            huida6 = args2[4]
            shuchu = huida2+huida3+huida5+huida6
            return shuchu
        else:
            return 1
    elif huida == "圆形":
        huida1 = mode
        huida2 = args2[0]
        if huida1 == "面积":
            shuchu = math.pi*(huida2**2)
            return shuchu
        elif huida1 == "周长":
            shuchu = 2*math.pi*huida2
            return shuchu
        elif huida1 == "方中圆":
            shuchu = 0.86 * (huida2 ** 2)
            return shuchu
        elif huida1 == "圆中方":
            shuchu = 1.14 * (huida2 ** 2)
            return shuchu
        else:
            return 1
    else:
        return 2




# coding:UTF-8
import setuptools

setuptools.setup(
    name="Allinonechay",
    version="4.0.3",
    author="Chay",
    author_email="lichenyi_2020@qq.com",
    url="https://github.com/lichenyichay/All-in-one-Including/",
    description="All-in-one",
    long_description="多功能一体机",
    python_requires=">=3.5",
    install_requires=["sympy>=1.13.1","mpmath>=1.3.0","lotterytickets>=2.0.0","numberandchinese>=1.0.0"],
    packages_dir={"": "src"},
    packages_data={"": ["*.txt", "*.info", "*.properties"], "": ["data/*.*"]},
    exclude=["*.test", "*.test.*", "test.*", "test"],
    classifiers=['Environment :: Web Environment',
                 'Intended Audience :: Developers',
                 "License :: OSI Approved :: MIT License",
                 "Operating System :: OS Independent",
                 "Programming Language :: Python",
                 "Programming Language :: Python :: 2",
                 "Programming Language :: Python :: 3"
                 ]
)



# -*- coding:UTF-8 -*-
# @Author:Chay
# @TIME:2022/12/24 15:38
# @FILE:math_cal_py.py
# @Software:IDLE 3.9.6
import math
'''
函数名：math_cal
调用形式：s = math_cal(mode,float1,float2)
:param mode 模式 1~19 模式不在此选择范围内会抛出异常
:param float1 float2 float型参数，根据模式的需求，如参数有空余，则空余参数添0即可，例：mode = 3:math_cal(3,5.2,0);
例2：mode = 4:math_cal(4,0,0);例3：mode = 1:math_cal(1,5.92,-8)
:return 结果
'''
def math_cal(mode:int,float1:float,float2:float):
    if mode == 1:
        return math.copysign(float1,float2)
    elif mode == 2:
        return math.cos(float1)
    elif mode == 3:
        return math.degrees(float1)
    elif mode == 4:
        return math.e
    elif mode == 5:
        return math.pi
    elif mode == 6:
        return math.tan(float1)
    elif mode == 7:
        return math.sqrt(float1)
    elif mode == 8:
        return math.sin(float1)
    elif mode == 9:
        return math.radians(float1)
    elif mode == 10:
        return math.pow(float1,float2)
    elif mode == 11:
        return math.modf(float1)
    elif mode == 12:
        return math.log(float1,float2)
    elif mode == 13:
        return math.ldexp(float1,float2)
    elif mode == 14:
        return not math.isnan(float1)
    elif mode == 15:
        return not math.isinf(float1)
    elif mode == 16:
        return math.factorial(int(float1))
    elif mode == 17:
        return math.fabs(float1)
    elif mode == 18:
        return math.exp(float1)
    else:
        raise TypeError("TypeError:类型错误！")



import os,time,csv,shutil
book = {}   # 书名字典，格式：书名:本数
jiebook = {} # 借书清单

def jieshu(name,count):          #借书
    if name in book.keys():
        if book[name] < 0:
            del book[name]
        if name not in jiebook.keys():
            book[name] -= count
            jiebook.update({name:1})
            if book[name] < 0:
                del book[name]
            print("借书成功！")
            return 0
        else:
            print("请先还书后再借阅，操作失败！")
            return 1
    else:
        print("书目不存在，操作失败！")
        return 1
def huanshu(name,count):          #还书
    if name in book.keys():
        if name in jiebook.keys():
            book[name] += count
            jiebook[name] -= count
            if book[name] < 0:
                del book[name]
            if jiebook[name] < 0:
                del jiebook[name]
            print("还书成功！")
            return 0
        else:
            print("未查询到借阅记录，无法还书，操作失败！")
            return 1
    else:
        print("书目不存在！")
        return 1
def jiashu(name,count):          #在库存内加书
    if name in book.keys():
        book[name] += count
    else:
        book[name] = count
    print("操作成功！")
    return 0
def jianshu(name,count):       #在库存内减书
    if name in book.keys():
        book[name] -= count
        if book[name] < 0:
            del book[name]
        print("操作成功！")
        return 0
    else:
        print("书目不存在，操作失败！")
        return 1
def jiebooksavetocsv(mode):
    try:
        with open("D:\\图书管理系统\\借书清单.csv",mode,encoding="UTF-8",newline="") as f:
            csv_writer = csv.writer(f)
            for i in jiebook:
                csv_writer.writerow([i,jiebook[i]])
    except:
        with open("D:\\图书管理系统\\借书清单.csv","w",encoding="UTF-8",newline="") as f:
            csv_writer = csv.writer(f)
            csv_writer.writerow(["书名","本数"])
            for i in jiebook:
                csv_writer.writerow([i,jiebook[i]])
def booksavetocsv(mode):
    try:
        with open("D:\\图书管理系统\\图书清单.csv",mode,encoding="UTF-8",newline="") as f:
            csv_writer = csv.writer(f)
            for i in book:
                csv_writer.writerow([i,book[i]])
    except:
        with open("D:\\图书管理系统\\图书清单.csv","w",encoding="UTF-8",newline="") as f:
            csv_writer = csv.writer(f)
            csv_writer.writerow(["书名","本数"])
            for i in book: 
                csv_writer.writerow([i,book[i]])
def printjiebook():
    print("------借书清单------")
    print("书名          本数")
    for i in jiebook:
        print(i,"        ",jiebook[i])
    jiebooksavetocsv("w")
    return 0
def bookquery(name):
    a = {}
    for i in book.keys():
        if name in i:
            a[i] = book[i]
    if len(a) != 0:
        print("------查询结果------")
        print("书名          本数")
        for i in a:
            print(i,"        ",a[i])
    else:
        print("查询失败！")
        return 1
    return 0
def printbook():
    print("------库存清单------")
    print("书名          本数")
    for i in book:
        print(i,"        ",book[i])
    booksavetocsv("w")
    return 0
def startmenu():
    print("------处理原数据------")
    print("1、初始化（删除）")
    print("2、保留")
    return 0
def book(*args3):
    while True:
        try:
            try:
                if os.path.exists("D:\\图书管理系统"):
                    while True:
                        os.system("cls")
                        startmenu()
                        a = input("请输入序号：")
                        if a == "1":
                            shutil.rmtree("D:\\图书管理系统")
                            password = 0
                            password = input("请设置管理员密码：")
                            os.makedirs("D:\\图书管理系统")
                            with open("D:\\图书管理系统\\password.txt","w") as file:
                                file.write(password)
                            break
                        elif a == "2":
                            with open("D:\\图书管理系统\\借书清单.csv") as f:
                                f_csv = csv.reader(f)
                                headers = next(f_csv)
                                for row in f_csv:
                                    jiebook[row[0]] = row[1]
                            with open("D:\\图书管理系统\\图书清单.csv") as f:
                                f_csv = csv.reader(f)
                                headers = next(f_csv)
                                for row in f_csv:
                                    book[row[0]] = row[1]
                            break
                        else:
                            print("序号错误！")
            except Exception as e:
                print(repr(e))
            os.system("cls")
            try:
                with open("D:\\图书管理系统\\password.txt","r") as file:
                    password = file.read()
            except Exception:
                password = input("请设置管理员密码：")
                os.makedirs("D:\\图书管理系统")
                with open("D:\\图书管理系统\\password.txt","w") as file:
                    file.write(password)
            while True:
                os.system("cls")
                xuhao = input("请输入序号：")
                if xuhao == "1":
                    try:
                        while True:
                            os.system("cls")
                            xuhao1 = input("请输入序号：")
                            if xuhao1 == "1":
                                a = input("请输入书本名称：")
                                jieshu(a,1)
                            elif xuhao1 == "2":
                                a = input("请输入书本名称：")
                                huanshu(a,1)
                            elif xuhao1 == "3":
                                a = input("请输入关键词：")
                                bookquery(a)
                            elif xuhao1 == "4":
                                printjiebook()
                            elif xuhao1 == "5":
                                break
                            else:
                                print("序号不存在！")
                    except Exception:
                        pass
                elif xuhao == "2":
                    try:
                        while True:
                            os.system("cls")
                            b = input("请输入管理员密码：")
                            if b == password:
                                os.system("cls")
                                xuhao1 = input("请输入序号：")
                                if xuhao1 == "1":
                                    a = input("请输入书本名称：")
                                    number = int(input("请输入本数："))
                                    jiashu(a,number)
                                elif xuhao1 == "2":
                                    a = input("请输入书本名称：")
                                    number = int(input("请输入本数："))
                                    jianshu(a,number)
                                elif xuhao1 == "3":
                                    printbook()
                                elif xuhao1 == "4":
                                    a = input("请输入关键词：")
                                    bookquery(a)
                                elif xuhao1 == "5":
                                    password = input("请设置新管理员密码：")
                                    with open("D:\\图书管理系统\\password.txt","w") as file:
                                        file.write(password)
                                    print("修改成功！")
                                    time.sleep(1)
                                elif xuhao1 == "6":
                                    break
                                else:
                                    print("序号不存在！")
                            else:
                                print("密码错误！")
                                break
                    except Exception:
                        pass
                elif xuhao == "3":
                    jiebooksavetocsv("w")
                    booksavetocsv("w")
                    break
                else:
                    print("序号不存在！")
            break
        except:
            pass



# -*- coding:UTF-8 -*-
# @Author:Chay
# @TIME:2022/12/25 9:02
# @FILE:student_py.py
# @Software:IDLE 3.9.6
'''
函数名：student
调用形式：student()
作用：小学学生信息管理系统
'''
def student():
    print("这里是xx小学学生信息管理系统")
    stu = { "老八"  : "老八,岁数不明,男,厕所深处 爱好:在厕所干饭"}
    print("你可以查到所有学员的个人信息,但也请不要向外泄露")
    while True:
        print("以下是现有学员名单：")
        for k in stu:
            print(k)
        ans = input("请输入功能：")
        if ans == "查询学生信息":
            try:
                a = input("请输入学员姓名：")
                return f"{a}的相关信息是：{stu[a]}"
            except:
                return "无此学生"
        elif ans == "删除学生信息":
            a = input("请输入要删除的学员姓名：")
            del stu[a]
            return f"{a}的相关信息已经删除"
        elif ans == "添加学生信息":
            a = input("请输入要添加的学员姓名：")
            b = input("请输入新增的学员信息：")
            stu[a] = b
            return (f"{a}的相关信息已添加")
        elif ans == "4":
            break
        else:
            return ("无此功能")
    return 0
